==> kst-1.1.0_dr1.tar.gz: kst-1.1.0_dr1/kst/kst/eparse-eh.h <==
/***************************************************************************
                               eparse-eh.h
                             ----------------
    begin                : Nov. 24, 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/* This file must be C-clean */

#ifndef EPARSEEH_H
#define EPARSEEH_H

#ifdef __cplusplus
namespace Equation {
  extern QStringList errorStack;
};
#endif

#ifdef __cplusplus
extern "C" {
#endif
  void yyerror(const char *s);
  void yyerrortoken(char c);

  void yyClearErrors();

  int yyErrorCount();

  extern const char *EParseErrorEmpty;
  extern const char *EParseErrorEmptyArg;
  extern const char *EParseErrorTwoOperands;
  extern const char *EParseErrorEmptyParentheses;
  extern const char *EParseErrorMissingClosingParenthesis;
  extern const char *EParseErrorNoImplicitMultiply;
  extern const char *EParseErrorRequiresOperand;
#ifdef __cplusplus
};
#endif

#endif

/*
vim: ts=2 sw=2 et
*/

==> kst-1.2.0dr1.tar.gz: kst-1.2.0dr1/kst/kst/eparse-eh.h <==
/***************************************************************************
                               eparse-eh.h
                             ----------------
    begin                : Nov. 24, 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/* This file must be C-clean */

#ifndef EPARSEEH_H
#define EPARSEEH_H

#ifdef __cplusplus

#include "kst_export.h"

namespace Equation {
   KST_EXPORT extern QStringList errorStack;
}
#endif

#ifdef __cplusplus
extern "C" {
#endif
  void yyerror(const char *s);
  void yyerrortoken(char c);

  void yyClearErrors();

  int yyErrorCount();

  extern const char *EParseErrorEmpty;
  extern const char *EParseErrorEmptyArg;
  extern const char *EParseErrorTwoOperands;
  extern const char *EParseErrorEmptyParentheses;
  extern const char *EParseErrorMissingClosingParenthesis;
  extern const char *EParseErrorNoImplicitMultiply;
  extern const char *EParseErrorRequiresOperand;
#ifdef __cplusplus
}
#endif

#endif

/*
vim: ts=2 sw=2 et
*/
